# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class LocalNFSDatasetCreateAPIPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cluster_id': 'int',
        'description': 'str',
        'minio_access_key': 'str',
        'minio_endpoint': 'str',
        'minio_secret_key': 'str',
        'name': 'str',
        'path': 'str',
        'server': 'str'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'description': 'description',
        'minio_access_key': 'minio_access_key',
        'minio_endpoint': 'minio_endpoint',
        'minio_secret_key': 'minio_secret_key',
        'name': 'name',
        'path': 'path',
        'server': 'server'
    }

    def __init__(self, cluster_id=None, description=None, minio_access_key=None, minio_endpoint=None, minio_secret_key=None, name=None, path=None, server=None, local_vars_configuration=None):  # noqa: E501
        """LocalNFSDatasetCreateAPIPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cluster_id = None
        self._description = None
        self._minio_access_key = None
        self._minio_endpoint = None
        self._minio_secret_key = None
        self._name = None
        self._path = None
        self._server = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.description = description
        self.minio_access_key = minio_access_key
        self.minio_endpoint = minio_endpoint
        self.minio_secret_key = minio_secret_key
        self.name = name
        self.path = path
        self.server = server

    @property
    def cluster_id(self):
        """Gets the cluster_id of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501


        :return: The cluster_id of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :rtype: int
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this LocalNFSDatasetCreateAPIPayload.


        :param cluster_id: The cluster_id of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :type cluster_id: int
        """
        if self.local_vars_configuration.client_side_validation and cluster_id is None:  # noqa: E501
            raise ValueError("Invalid value for `cluster_id`, must not be `None`")  # noqa: E501

        self._cluster_id = cluster_id

    @property
    def description(self):
        """Gets the description of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501


        :return: The description of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this LocalNFSDatasetCreateAPIPayload.


        :param description: The description of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def minio_access_key(self):
        """Gets the minio_access_key of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501


        :return: The minio_access_key of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._minio_access_key

    @minio_access_key.setter
    def minio_access_key(self, minio_access_key):
        """Sets the minio_access_key of this LocalNFSDatasetCreateAPIPayload.


        :param minio_access_key: The minio_access_key of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :type minio_access_key: str
        """

        self._minio_access_key = minio_access_key

    @property
    def minio_endpoint(self):
        """Gets the minio_endpoint of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501


        :return: The minio_endpoint of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._minio_endpoint

    @minio_endpoint.setter
    def minio_endpoint(self, minio_endpoint):
        """Sets the minio_endpoint of this LocalNFSDatasetCreateAPIPayload.


        :param minio_endpoint: The minio_endpoint of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :type minio_endpoint: str
        """

        self._minio_endpoint = minio_endpoint

    @property
    def minio_secret_key(self):
        """Gets the minio_secret_key of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501


        :return: The minio_secret_key of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._minio_secret_key

    @minio_secret_key.setter
    def minio_secret_key(self, minio_secret_key):
        """Sets the minio_secret_key of this LocalNFSDatasetCreateAPIPayload.


        :param minio_secret_key: The minio_secret_key of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :type minio_secret_key: str
        """

        self._minio_secret_key = minio_secret_key

    @property
    def name(self):
        """Gets the name of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501


        :return: The name of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LocalNFSDatasetCreateAPIPayload.


        :param name: The name of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def path(self):
        """Gets the path of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501


        :return: The path of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this LocalNFSDatasetCreateAPIPayload.


        :param path: The path of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :type path: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def server(self):
        """Gets the server of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501


        :return: The server of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this LocalNFSDatasetCreateAPIPayload.


        :param server: The server of this LocalNFSDatasetCreateAPIPayload.  # noqa: E501
        :type server: str
        """
        if self.local_vars_configuration.client_side_validation and server is None:  # noqa: E501
            raise ValueError("Invalid value for `server`, must not be `None`")  # noqa: E501

        self._server = server

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocalNFSDatasetCreateAPIPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LocalNFSDatasetCreateAPIPayload):
            return True

        return self.to_dict() != other.to_dict()
